From linux-kernel-owner+greg=40kroah.com-S932163AbVHKVgQ@vger.kernel.org Thu Aug 11 14:42:00 2005
Date: Thu, 11 Aug 2005 23:36:49 +0200
From: Jean Delvare <khali@linux-fr.org>
Subject: I2C: Kill i2c_algorithm.id (2/7)
Message-Id: <20050811233649.472cfa05.khali@linux-fr.org>

Use the adapter id rather than the algorithm id to detect the i2c-isa
pseudo-adapter. This saves one level of dereferencing, and the
algorithm ids will soon be gone anyway.

Signed-off-by: Jean Delvare <khali@linux-fr.org>
Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>


---
 drivers/i2c/busses/i2c-isa.c |    1 +
 include/linux/i2c-isa.h      |    6 +++---
 2 files changed, 4 insertions(+), 3 deletions(-)

--- gregkh-2.6.orig/drivers/i2c/busses/i2c-isa.c	2005-08-12 14:37:49.000000000 -0700
+++ gregkh-2.6/drivers/i2c/busses/i2c-isa.c	2005-08-12 14:37:53.000000000 -0700
@@ -50,6 +50,7 @@
 /* There can only be one... */
 static struct i2c_adapter isa_adapter = {
 	.owner		= THIS_MODULE,
+	.id		= I2C_ALGO_ISA | I2C_HW_ISA,
 	.class          = I2C_CLASS_HWMON,
 	.algo		= &isa_algorithm,
 	.name		= "ISA main adapter",
--- gregkh-2.6.orig/include/linux/i2c-isa.h	2005-08-12 14:12:10.000000000 -0700
+++ gregkh-2.6/include/linux/i2c-isa.h	2005-08-12 14:37:53.000000000 -0700
@@ -28,9 +28,9 @@
 
 /* Detect whether we are on the isa bus. This is only useful to hybrid
    (i2c+isa) drivers. */
-#define i2c_is_isa_client(clientptr) \
-        ((clientptr)->adapter->algo->id == I2C_ALGO_ISA)
 #define i2c_is_isa_adapter(adapptr) \
-        ((adapptr)->algo->id == I2C_ALGO_ISA)
+        ((adapptr)->id == (I2C_ALGO_ISA | I2C_HW_ISA))
+#define i2c_is_isa_client(clientptr) \
+        i2c_is_isa_adapter((clientptr)->adapter)
 
 #endif /* _LINUX_I2C_ISA_H */
